Function get_stylus_program_count
pub fn get_stylus_program_count(addr: Address) -> u32Expand description
Get the current Stylus program count for an address (no mutation).
pub fn get_stylus_program_count(addr: Address) -> u32Get the current Stylus program count for an address (no mutation).