ArbEvmFactoryStaged

Trait ArbEvmFactoryStaged 

pub trait ArbEvmFactoryStaged {
    // Required method
    fn staged_precompile_ctx(&self) -> Option<Arc<ArbPrecompileCtx>>;
}
Accessor for the Arc<ArbPrecompileCtx> that an EVM factory most recently staged for the next [EvmFactory::create_evm] call. The block executor reuses this Arc so its per-tx writes share an allocation with the EVM precompile handler closures (which capture the Arc at registration time).

Required Methods

Implementors