push_stylus_program

Function push_stylus_program 

pub fn push_stylus_program(addr: Address) -> bool
Push a Stylus program address onto the reentrancy tracker. Returns true if this is a reentrant call (address was already active).